==> hyades.source_1.2.0_20040115_0724.zip: org/eclipse/hyades/internal/execution/recorder/remote/RecorderCommandHandler.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.internal.execution.recorder.remote;

import java.util.StringTokenizer;

import org.eclipse.hyades.execution.core.IControlMessage;
import org.eclipse.hyades.internal.execution.local.common.CustomCommand;
import org.eclipse.hyades.internal.execution.recorder.remote.appadapters.RecorderApplicationAdapterException;
import org.eclipse.hyades.internal.execution.remote.CustomCommandHandler;


/**
 * Handles control commands from the RAC by passing them to the appropriate RecorderAgentController method
 * @author Ernest Jessee
 */
public class RecorderCommandHandler implements CustomCommandHandler
{

	/**
	 * RecorderAgentController which instantiated the RecorderCommandHandler and registered it.
	 */
	private RecorderAgentController parent;
	
	
	/**
	 * constructor
	 */
	public RecorderCommandHandler(RecorderAgentController recorderController)
	{
		parent = recorderController;
	}
	
	/**
	 * @see org.eclipse.hyades.internal.execution.remote.CustomCommandHandler#handleCommand(org.eclipse.hyades.internal.execution.local.common.CustomCommand)
	 */
	public void handleCommand(CustomCommand command)
	{
		try
		{
			if(command.getData().equals(IControlMessage.START))
			{		
				 handleStartCommand();
			}		
			else if(command.getData().startsWith("StartRecording")) //$NON-NLS-1$
			{
				handleStartRecordingCommand();
			}
			else if(command.getData().startsWith("StartApp")) //$NON-NLS-1$
			{
				handleStartAppCommand(command);			
			}
			else if(command.getData().startsWith("StopApp")) //$NON-NLS-1$
			{
				handleStopAppCommand(command);			
			}
			else if(command.getData().startsWith("Init")) //$NON-NLS-1$
			{
				handleInitCommand(command);			
			}
			else if(command.getData().startsWith("Stop")) //$NON-NLS-1$
			{
				handleStopCommand(command);
			}
			else
			{
				parent.sendDebugMessageToDataProcessor("un-interpreted command: "+command.getData()); //$NON-NLS-1$
			}
		}
		catch (RecorderApplicationAdapterException e)
		{
			parent.reportException("error processing command "+command.getData(),e); //$NON-NLS-1$
		}
	}
	
	
	
	private void handleStopCommand(CustomCommand command)
	{
		parent.stopRecording();	
		
	}
	
	private void handleStopAppCommand(CustomCommand command)
	{
		parent.stopApp();	
	
	}
	
	private void handleStartAppCommand(CustomCommand command)throws RecorderApplicationAdapterException
	{
		String commandString = stripFlag(command);
		StringTokenizer commandTokenizer = new StringTokenizer(commandString,";"); //$NON-NLS-1$
		
		String adapterClassPath = null;
		String adapterInitString = ""; //$NON-NLS-1$
		
		if(commandTokenizer.countTokens()<1)
			throw new RecorderApplicationAdapterException("start app info incorrect"); //$NON-NLS-1$
			
		adapterClassPath = commandTokenizer.nextToken();
		while(commandTokenizer.hasMoreTokens())
			adapterInitString+=commandTokenizer.nextToken();
		
		parent.startApplication(adapterClassPath,adapterInitString);	
	}
	
	
	private String stripFlag(CustomCommand command)
	{
		String initInfo = command.getData();
		initInfo = initInfo.substring(initInfo.indexOf(" "),initInfo.length()); //$NON-NLS-1$
		return initInfo.trim();
	}
		
	
	private void handleStartCommand()
	{
		parent.setOKToStart(true);
	}
	
	private void handleInitCommand(CustomCommand command)
	{
		parent.initAgent(stripFlag(command));				
			
	}
	
	
	private void handleStartRecordingCommand()
	{
		parent.startRecording();			
	}
	

}

==> hyades.source_1.3.0_20040422_2239.zip: org/eclipse/hyades/internal/execution/recorder/remote/RecorderCommandHandler.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.internal.execution.recorder.remote;

import org.eclipse.hyades.execution.core.IControlMessage;
import org.eclipse.hyades.internal.execution.local.common.CustomCommand;
import org.eclipse.hyades.internal.execution.remote.CustomCommandHandler;


/**
 * Handles control commands from the RAC by passing them to the appropriate RecorderAgentController method
 * @author Ernest Jessee
 */
public class RecorderCommandHandler implements CustomCommandHandler
{

	/**
	 * RecorderAgentController which instantiated the RecorderCommandHandler and registered it.
	 */
	private RecorderAgentController parent;
	
	
	/**
	 * constructor
	 */
	public RecorderCommandHandler(RecorderAgentController recorderController)
	{
		parent = recorderController;
	}
	
	/**
	 * @see org.eclipse.hyades.internal.execution.remote.CustomCommandHandler#handleCommand(org.eclipse.hyades.internal.execution.local.common.CustomCommand)
	 */
	public void handleCommand(CustomCommand command)
	{
		try
		{
			if(command.getData().equals(IControlMessage.START))
			{		
				 handleStartCommand();
			}		
			else if(command.getData().startsWith("StartRecording")) //$NON-NLS-1$
			{
				handleStartRecordingCommand();
			}
			/*  //start app moved to local

			else if(command.getData().startsWith("StartApp")) //$NON-NLS-1$
			{
				handleStartAppCommand(command);			
			}
			*/
			/* //stop app moved to local
			else if(command.getData().startsWith("StopApp")) //$NON-NLS-1$
			{
				handleStopAppCommand(command);			
			}
			*/
			else if(command.getData().startsWith("Init")) //$NON-NLS-1$
			{
				handleInitCommand(command);			
			}
			else if(command.getData().startsWith("Stop")) //$NON-NLS-1$
			{
				handleStopCommand(command);
			}
			else
			{
				parent.sendDebugMessageToDataProcessor("un-interpreted command: "+command.getData()); //$NON-NLS-1$
			}
		}
		catch (Exception e)
		{
			parent.reportException("error processing command "+command.getData(),e); //$NON-NLS-1$
		}
	}
	
	
	
	private void handleStopCommand(CustomCommand command)
	{
		parent.stopRecording();	
		
	}
	
	
	private String stripFlag(CustomCommand command)
	{
		String initInfo = command.getData();
		initInfo = initInfo.substring(initInfo.indexOf(" "),initInfo.length()); //$NON-NLS-1$
		return initInfo.trim();
	}
		
	
	private void handleStartCommand()
	{
		parent.setOKToStart(true);
	}
	
	private void handleInitCommand(CustomCommand command)
	{
		parent.initAgent(stripFlag(command));				
			
	}
	
	
	private void handleStartRecordingCommand()
	{
		parent.startRecording();			
	}
	

}
